@@ -1,10 +1,10 @@
 leaflet_classes <-
-function(data,fondMaille,fondMailleElargi=NULL,fondSuppl=NULL,idData,varRatio,methode="kmeans",nbClasses=3,bornes=NULL,stylePalette="defaut",opacityElargi=0.6,colBorder="white",precision=1,dom="0",zoomMaille=NULL,map_proxy=NULL)
+function(data,fondMaille,fondMailleElargi=NULL,fondSuppl=NULL,idData,varRatio,methode="kmeans",nbClasses=3,bornes=NULL,stylePalette="defaut",opacityElargi=0.6,colBorder="white",precision=1,emprise="FRM",fondEtranger=NULL,zoomMaille=NULL,map_proxy=NULL)
   {
     options("stringsAsFactors"=FALSE)
     
     # Verification des parametres
-    leafletVerifParamClasses(data,fondMaille,fondMailleElargi,fondSuppl,idData,varRatio,methode,nbClasses,bornes,stylePalette,opacityElargi,colBorder,precision,dom,map_proxy)
+    leafletVerifParamClasses(data,fondMaille,fondMailleElargi,fondSuppl,idData,varRatio,methode,nbClasses,bornes,stylePalette,opacityElargi,colBorder,precision,emprise,fondEtranger,map_proxy)
     
     names(data)[names(data)==idData] <- "CODE"
     names(fondMaille)[1] <- "CODE"
@@ -21,7 +21,19 @@ function(data,fondMaille,fondMailleElargi=NULL,fondSuppl=NULL,idData,varRatio,me
       names(fondSuppl)[2] <- "LIBELLE"
       fondSuppl$LIBELLE<-iconv(fondSuppl$LIBELLE,"latin1","utf8")
     }
-    
+    epsg_etranger <- NULL
+    if(!is.null(fondEtranger)) 
+    {
+      names(fondEtranger)[1] <- "CODE"
+      names(fondEtranger)[2] <- "LIBELLE"
+      fondEtranger$LIBELLE<-iconv(fondEtranger$LIBELLE,"latin1","utf8")
+      
+      epsg_etranger <- st_crs(fondEtranger)$epsg
+      if(is.na(epsg_etranger) | epsg_etranger=="4326")
+      {
+        epsg_etranger <- "3395" # Mercator
+      }
+    }
     fondMaille$LIBELLE<-iconv(fondMaille$LIBELLE,"latin1","utf8")
     
     if(!is.null(map_proxy))
@@ -41,13 +53,14 @@ function(data,fondMaille,fondMailleElargi=NULL,fondSuppl=NULL,idData,varRatio,me
       elargi <- TRUE
     }
     
-    code_epsg <- switch(dom, #DOM
-                        "0"="2154",# Lambert 93
+    code_epsg <- switch(emprise,
+                        "FRM"="2154",# Lambert 93
                         "971"="32620",# UTM 20 N
                         "972"="32620",# UTM 20 N
                         "973"="2972",# UTM 22 N
                         "974"="2975",# UTM 40 S
-                        "976"="4471")# UTM 38 S
+                        "976"="4471",# UTM 38 S
+                        "999"=epsg_etranger)
     
     # Analyse
     data[,varRatio] <- round(data[,varRatio],precision)
@@ -165,40 +178,42 @@ function(data,fondMaille,fondMailleElargi=NULL,fondSuppl=NULL,idData,varRatio,me
     
     # Fonds habillages
     
-    if(dom=="0")
+    if(emprise=="FRM")
     {
-      pays <- st_transform(sf_paysm(),"+init=epsg:4326 +proj=longlat +ellps=WGS84")
-      fra <- st_transform(sf_fram(),"+init=epsg:4326 +proj=longlat +ellps=WGS84")
-    }else
+      fond_pays <- st_transform(sf_paysm(),"+init=epsg:4326 +proj=longlat +ellps=WGS84")
+      fond_france <- st_transform(sf_fram(),"+init=epsg:4326 +proj=longlat +ellps=WGS84")
+    }else if(emprise!="999")
     {
-      if(dom=="971")
+      if(emprise=="971")
       {
-        fra <- st_transform(sf_reg01(),"+init=epsg:4326 +proj=longlat +ellps=WGS84")
-        pays <- fra
+        fond_france <- st_transform(sf_reg01(),"+init=epsg:4326 +proj=longlat +ellps=WGS84")
+        fond_pays <- fond_france
       }
-      if(dom=="972")
+      if(emprise=="972")
       {
-        fra <- st_transform(sf_reg02(),"+init=epsg:4326 +proj=longlat +ellps=WGS84")
-        pays <- fra
+        fond_france <- st_transform(sf_reg02(),"+init=epsg:4326 +proj=longlat +ellps=WGS84")
+        fond_pays <- fond_france
       }
-      if(dom=="973")
+      if(emprise=="973")
       {
-        fra <- st_transform(sf_reg03(),"+init=epsg:4326 +proj=longlat +ellps=WGS84")
-        pays <- st_transform(sf_pays973(),"+init=epsg:4326 +proj=longlat +ellps=WGS84")
+        fond_france <- st_transform(sf_reg03(),"+init=epsg:4326 +proj=longlat +ellps=WGS84")
+        fond_pays <- st_transform(sf_pays973(),"+init=epsg:4326 +proj=longlat +ellps=WGS84")
       }
-      if(dom=="974")
+      if(emprise=="974")
       {
-        fra <- st_transform(sf_reg04(),"+init=epsg:4326 +proj=longlat +ellps=WGS84")
-        pays <- fra
+        fond_france <- st_transform(sf_reg04(),"+init=epsg:4326 +proj=longlat +ellps=WGS84")
+        fond_pays <- fond_france
       }
-      if(dom=="976")
+      if(emprise=="976")
       {
-        fra <- st_transform(sf_reg06(),"+init=epsg:4326 +proj=longlat +ellps=WGS84")
-        pays <- fra
+        fond_france <- st_transform(sf_reg06(),"+init=epsg:4326 +proj=longlat +ellps=WGS84")
+        fond_pays <- fond_france
       }
-    }
-    fond_france <- fra
-    fond_pays <- pays
+    }else if(emprise=="999")
+    {
+      fond_etranger <- st_transform(fondEtranger,"+init=epsg:4326 +proj=longlat +ellps=WGS84")
+      fond_pays <- fond_etranger
+    }else{}
     
     maille_WGS84 <- st_transform(fondMaille,"+init=epsg:4326 +proj=longlat +ellps=WGS84")
     
@@ -249,11 +264,12 @@ function(data,fondMaille,fondMailleElargi=NULL,fondSuppl=NULL,idData,varRatio,me
         
         # Pour gerer l'ordre des calques
         addMapPane(name = "fond_pays", zIndex = 401) %>%
-        addMapPane(name = "fond_france", zIndex = 402) %>%
-        addMapPane(name = "fond_territoire", zIndex = 403) %>%
-        addMapPane(name = "fond_classes_elargi", zIndex = 404) %>%
-        addMapPane(name = "fond_classes", zIndex = 405) %>%
-        addMapPane(name = "fond_legende", zIndex = 406) %>%
+        addMapPane(name = "fond_etranger", zIndex = 402) %>%
+        addMapPane(name = "fond_france", zIndex = 403) %>%
+        addMapPane(name = "fond_territoire", zIndex = 404) %>%
+        addMapPane(name = "fond_classes_elargi", zIndex = 405) %>%
+        addMapPane(name = "fond_classes", zIndex = 406) %>%
+        addMapPane(name = "fond_legende", zIndex = 407) %>%
         
         # On ajoute une barre d'echelle
         addScaleBar(position = 'bottomright',
@@ -261,29 +277,51 @@ function(data,fondMaille,fondMailleElargi=NULL,fondSuppl=NULL,idData,varRatio,me
         )
       
       # AFFICHAGE DES FONDS D'HABILLAGE
-      if(dom %in% c("0","973"))
+
+      if(emprise %in% c("FRM","973")) # France metro ou Guyane
       {
-        map <- addPolygons(map = map, data = fond_pays[,"LIBGEO"], opacity = 1, # fond_pays sauf la France
+        map <- addPolygons(map = map, data = fond_pays[,"LIBGEO"], opacity = 1,
                            stroke = TRUE, color = "white",
                            weight = 1,
                            popup = as.data.frame(fond_pays[,"LIBGEO"])[,-ncol(as.data.frame(fond_pays[,"LIBGEO"]))],
-                           options = pathOptions(pane = "fond_pays", clickable = F),
+                           options = pathOptions(pane = "fond_pays", clickable = T),
                            fill = T, fillColor = "#CCCCCC", fillOpacity = 1,
                            group = "carte_classes_init",
                            layerId = list(fond_pays=fond_pays,code_epsg=code_epsg,nom_fond="fond_pays")
-                           
+        )
+        
+        map <- addPolygons(map = map, data = fond_france[,"LIBGEO"], opacity = 1,
+                           stroke = TRUE, color = "black",
+                           weight = 1.5,
+                           popup = as.data.frame(fond_france[,"LIBGEO"])[,-ncol(as.data.frame(fond_france[,"LIBGEO"]))],
+                           options = pathOptions(pane = "fond_france", clickable = T),
+                           fill = T, fillColor = "white", fillOpacity = 1,
+                           group = "carte_classes_init",
+                           layerId = list(fond_france=fond_france,code_epsg=code_epsg,nom_fond="fond_france")
+        )
+      }else if(!emprise %in% c("999")) # 971, 972, 974 ou 976
+      {
+        map <- addPolygons(map = map, data = fond_france[,"LIBGEO"], opacity = 1,
+                           stroke = TRUE, color = "black",
+                           weight = 1.5,
+                           popup = as.data.frame(fond_france[,"LIBGEO"])[,-ncol(as.data.frame(fond_france[,"LIBGEO"]))],
+                           options = pathOptions(pane = "fond_france", clickable = T),
+                           fill = T, fillColor = "white", fillOpacity = 1,
+                           group = "carte_classes_init",
+                           layerId = list(fond_france=fond_france,code_epsg=code_epsg,nom_fond="fond_france")
+        )
+      }else if(emprise %in% c("999")) # Etranger
+      {
+        map <- addPolygons(map = map, data = fond_etranger[,"LIBELLE"], opacity = 1,
+                           stroke = TRUE, color = "black",
+                           weight = 1,
+                           popup = as.data.frame(fond_etranger[,"LIBELLE"])[,-ncol(as.data.frame(fond_etranger[,"LIBELLE"]))],
+                           options = pathOptions(pane = "fond_etranger", clickable = T),
+                           fill = T, fillColor = "white", fillOpacity = 1,
+                           group = "carte_classes_init",
+                           layerId = list(fond_etranger=fond_etranger,code_epsg=code_epsg,nom_fond="fond_etranger")
         )
       }
-      
-      map <- addPolygons(map = map, data = fond_france[,"LIBGEO"], opacity = 1, # fond_france
-                         stroke = TRUE, color = "black",
-                         weight = 1.5,
-                         popup = as.data.frame(fond_france[,"LIBGEO"])[,-ncol(as.data.frame(fond_france[,"LIBGEO"]))],
-                         options = pathOptions(pane = "fond_france", clickable = F),
-                         fill = T, fillColor = "white", fillOpacity = 1,
-                         group = "carte_classes_init",
-                         layerId = list(fond_france=fond_france,code_epsg=code_epsg,nom_fond="fond_france")
-      )
     
       # AFFICHAGE DU FOND TERRITOIRE
       
@@ -322,7 +360,7 @@ function(data,fondMaille,fondMailleElargi=NULL,fondSuppl=NULL,idData,varRatio,me
                          fillColor = palette(analyse_maille_classe_elargi),
                          fillOpacity = opacityElargi,
                          group = "carte_classes_elargi",
-                         layerId = list(analyse_maille_elargi=analyse_maille_elargi,analyse_maille_classe_elargi=analyse_maille_classe_elargi,code_epsg=code_epsg,dom=dom,nom_fond="fond_maille_elargi_carte",bornes=bornes,var_ratio=varRatio,precision=precision,style=stylePalette,palette=pal_classes,col_border_classes=colBorder)
+                         layerId = list(analyse_maille_elargi=analyse_maille_elargi,analyse_maille_classe_elargi=analyse_maille_classe_elargi,code_epsg=code_epsg,emprise=emprise,nom_fond="fond_maille_elargi_carte",bornes=bornes,var_ratio=varRatio,precision=precision,style=stylePalette,palette=pal_classes,col_border_classes=colBorder)
       )
     }
     
@@ -342,7 +380,7 @@ function(data,fondMaille,fondMailleElargi=NULL,fondSuppl=NULL,idData,varRatio,me
                        fillColor = palette(analyse_maille_classe),
                        fillOpacity = 1,
                        group = "carte_classes",
-                       layerId = list(analyse_maille=analyse_maille,analyse_maille_classe=analyse_maille_classe,code_epsg=code_epsg,dom=dom,nom_fond="fond_maille_carte",bornes=bornes,var_ratio=varRatio,precision=precision,style=stylePalette,palette=pal_classes,col_border_classes=colBorder)
+                       layerId = list(analyse_maille=analyse_maille,analyse_maille_classe=analyse_maille_classe,code_epsg=code_epsg,emprise=emprise,nom_fond="fond_maille_carte",bornes=bornes,var_ratio=varRatio,precision=precision,style=stylePalette,palette=pal_classes,col_border_classes=colBorder)
     )
     
     return(map)
