@@ -74,7 +74,7 @@ function(map,colEntree="#CD853F",colSortie="#6495ED",colBorder="black",map_leafl
       analyse_WGS84 <- map_leaflet$x$calls[[idx_fleche]]$args[[2]]$analyse_WGS84
       donnees <- map_leaflet$x$calls[[idx_fleche]]$args[[2]]$donnees
       code_epsg <- map_leaflet$x$calls[[idx_fleche]]$args[[2]]$code_epsg
-      dom <- map_leaflet$x$calls[[idx_fleche]]$args[[2]]$dom
+      emprise <- map_leaflet$x$calls[[idx_fleche]]$args[[2]]$emprise
       varFlux <- map_leaflet$x$calls[[idx_fleche]]$args[[2]]$var_flux
       max_var <- map_leaflet$x$calls[[idx_fleche]]$args[[2]]$max_var
       largeurFlecheMax <- map_leaflet$x$calls[[idx_fleche]]$args[[2]]$largeur
@@ -89,7 +89,7 @@ function(map,colEntree="#CD853F",colSortie="#6495ED",colBorder="black",map_leafl
                          popup = paste0("<b><font color=#2B3E50>",donnees$CODE1," vers ",donnees$CODE2,"<br>",varFlux," : ",donnees[,varFlux],"</font></b>"),
                          fill = T, fillColor = sapply(donnees[,varFlux], function(x) if(x>0){colEntree}else{colSortie}), fillOpacity = 1,
                          group = "carte_saphirs",
-                         layerId = list(analyse_WGS84=analyse_WGS84,donnees=donnees,colEntree=colEntree,colSortie=colSortie,code_epsg=code_epsg,dom=dom,nom_fond="fond_flux",var_flux=varFlux,max_var=max(abs(donnees[,varFlux])),largeur=largeurFlecheMax,distance=large_pl)
+                         layerId = list(analyse_WGS84=analyse_WGS84,donnees=donnees,colEntree=colEntree,colSortie=colSortie,code_epsg=code_epsg,emprise=emprise,nom_fond="fond_flux",var_flux=varFlux,max_var=max(abs(donnees[,varFlux])),largeur=largeurFlecheMax,distance=large_pl)
       )
       
       if(!is.null(idx_legende))
