@@ -1,10 +1,10 @@
 shiny_oursins <-
-function(data,fondMaille,fondContour,fondSuppl=NULL,idDataDepart,idDataArrivee,varFlux,decalageAllerRetour=0,decalageCentroid=0,dom="0")
+function(data,fondMaille,fondContour,fondSuppl=NULL,idDataDepart,idDataArrivee,varFlux,decalageAllerRetour=0,decalageCentroid=0,emprise="FRM",fondEtranger=NULL)
   {
     options("stringsAsFactors"=FALSE)
     
     # Verification des parametres
-    msg_error1<-msg_error2<-msg_error3<-msg_error4<-msg_error5<-msg_error6<-msg_error7<-msg_error8<-msg_error9<-msg_error10<-msg_error11<-msg_error12<-msg_error13<-msg_error14<-msg_error15<-msg_error16<-msg_error17<-msg_error18 <- NULL
+    msg_error1<-msg_error2<-msg_error3<-msg_error4<-msg_error5<-msg_error6<-msg_error7<-msg_error8<-msg_error9<-msg_error10<-msg_error11<-msg_error12<-msg_error13<-msg_error14<-msg_error15<-msg_error16<-msg_error17<-msg_error18<-msg_error19<-msg_error20 <- NULL
     
     if(any(class(data)!="data.frame")) msg_error1 <- "Les donnees doivent etre dans un data.frame / "
     if(any(!any(class(fondMaille) %in% "sf"),!any(class(fondMaille) %in% "data.frame"))) msg_error2 <- "Le fond de maille doit etre un objet sf / "
@@ -15,7 +15,7 @@ function(data,fondMaille,fondContour,fondSuppl=NULL,idDataDepart,idDataArrivee,v
     if(any(class(varFlux)!="character")) msg_error7 <- "Le nom de la variable doit etre de type caractere / "
     if(any(class(decalageAllerRetour)!="numeric")) msg_error8 <- "La variable decalageAllerRetour doit etre de type numerique / "
     if(any(class(decalageCentroid)!="numeric")) msg_error9 <- "La variable decalageCentroid doit etre de type numerique / "
-    if(any(class(dom)!="character")) msg_error10 <- "La valeur doit etre de type caractere ('0', '971', '972', '973', '974' ou '976') / "
+    if(any(class(emprise)!="character")) msg_error10 <- "La valeur doit etre de type caractere ('FRM', '971', '972', '973', '974', '976' ou '999') / "
     
     if(length(names(data))<3) msg_error11 <- "Le tableau des donnees n'est pas conforme. Il doit contenir au minimum une variable identifiant de depart, une variable identifiant d'arrivee et la variable a representer / "
     if(length(names(fondMaille))<3) msg_error12 <- "Le fond de maille n'est pas conforme. La table doit contenir au minimum une variable identifiant, une variable libelle et la geometry / "
@@ -25,15 +25,18 @@ function(data,fondMaille,fondContour,fondSuppl=NULL,idDataDepart,idDataArrivee,v
     if(!any(names(data) %in% idDataDepart))  msg_error15 <- "La variable identifiant de depart n'existe pas dans la table des donnees / "
     if(!any(names(data) %in% idDataArrivee))  msg_error16 <- "La variable identifiant d'arrivee n'existe pas dans la table des donnees / "
     if(!any(names(data) %in% varFlux))  msg_error17 <- "La variable a representer n'existe pas dans la table des donnees / "
-    if(!dom %in% c("0","971","972","973","974","976")) msg_error18 <- "La variable dom doit etre '0', '971', '972', '973', '974' ou '976' / "
+    if(!emprise %in% c("FRM","971","972","973","974","976","999")) msg_error18 <- "La variable emprise doit etre 'FRM', '971', '972', '973', '974', '976' ou '999' / "
+    if(!is.null(fondEtranger)) if(any(!any(class(fondEtranger) %in% "sf"),!any(class(fondEtranger) %in% "data.frame"))) msg_error19 <- "Le fond etranger doit etre un objet sf / "
+    if(!is.null(fondEtranger)) if(length(names(fondEtranger))<3) msg_error20 <- "Le fond etranger n'est pas conforme. La table doit contenir au minimum une variable identifiant, une variable libelle et la geometry / "
     
     if(any(!is.null(msg_error1),!is.null(msg_error2),!is.null(msg_error3),!is.null(msg_error4),
            !is.null(msg_error5),!is.null(msg_error6),!is.null(msg_error7),!is.null(msg_error8),
            !is.null(msg_error10),!is.null(msg_error11),!is.null(msg_error12),!is.null(msg_error13),
-           !is.null(msg_error14),!is.null(msg_error15),!is.null(msg_error16),!is.null(msg_error17),!is.null(msg_error18)))
+           !is.null(msg_error14),!is.null(msg_error15),!is.null(msg_error16),!is.null(msg_error17),
+           !is.null(msg_error18),!is.null(msg_error19),!is.null(msg_error20)))
     {
       stop(simpleError(paste0(msg_error1,msg_error2,msg_error3,msg_error4,msg_error5,msg_error6,msg_error7,msg_error8,
-                              msg_error10,msg_error11,msg_error12,msg_error13,msg_error14,msg_error15,msg_error16,msg_error17,msg_error18)))
+                              msg_error10,msg_error11,msg_error12,msg_error13,msg_error14,msg_error15,msg_error16,msg_error17,msg_error18,msg_error19,msg_error20)))
     }
     
     nb_up <- reactiveValues(a=0)
@@ -58,6 +61,19 @@ function(data,fondMaille,fondContour,fondSuppl=NULL,idDataDepart,idDataArrivee,v
     names(fondMaille)[2] <- "LIBELLE"
     names(fondContour)[1] <- "CODE"
     names(fondContour)[2] <- "LIBELLE"
+    epsg_etranger <- NULL
+    if(!is.null(fondEtranger)) 
+    {
+      names(fondEtranger)[1] <- "CODE"
+      names(fondEtranger)[2] <- "LIBGEO"
+      fondEtranger$LIBGEO<-iconv(fondEtranger$LIBGEO,"latin1","utf8")
+      
+      epsg_etranger <- st_crs(fondEtranger)$epsg
+      if(is.na(epsg_etranger) | epsg_etranger=="4326")
+      {
+        epsg_etranger <- "3395" # Mercator
+      }
+    }
     if(!is.null(fondSuppl)) 
     {
       names(fondSuppl)[1] <- "CODE"
@@ -264,9 +280,9 @@ function(data,fondMaille,fondContour,fondSuppl=NULL,idDataDepart,idDataArrivee,v
                                br(),
                                strong(HTML("<font size=3>Par l'Outil Capture</font>")),
                                br(),
-                               HTML("<font size=2>1- Ouvrir le logiciel Outil Capture sur le Poste de travail (Menu D\u00e9marrer > Tous les programmes > Accessoires > Outil Capture).</font>"),
+                               HTML("<font size=2>1- Ouvrir un logiciel de capture (Outil Capture de Windows par exemple).</font>"),
                                br(),
-                               HTML(paste0("<font size=2>2- S\u00e9lectionner la zone \u00e0 capturer (vous aurez besoin d'adapter la fen\u00eatre AUS pour avoir \u00e0 la fois la carte et la barre des t","\u00e2","ches).</font>")),
+                               HTML(paste0("<font size=2>2- S\u00e9lectionner la zone \u00e0 capturer.</font>")),
                                br(),
                                HTML("<font size=2>3- Enregistrer l'image ou copier la dans le presse-papier.</font>"),
                                br(),
@@ -425,13 +441,14 @@ function(data,fondMaille,fondContour,fondSuppl=NULL,idDataDepart,idDataArrivee,v
       }
       
       code_epsg_ou <- reactive({
-        code_epsg <- switch(dom, #DOM
-                            "0"="2154",# Lambert 93
+        code_epsg <- switch(emprise,
+                            "FRM"="2154",# Lambert 93
                             "971"="32620",# UTM 20 N
                             "972"="32620",# UTM 20 N
                             "973"="2972",# UTM 22 N
                             "974"="2975",# UTM 40 S
-                            "976"="4471")# UTM 38 S
+                            "976"="4471",# UTM 38 S
+                            "999"=epsg_etranger)
         return(code_epsg)
       })
       
@@ -464,40 +481,42 @@ function(data,fondMaille,fondContour,fondSuppl=NULL,idDataDepart,idDataArrivee,v
       
       fond_habillage_ou <- reactive({
         
-        if(dom=="0")
+        if(emprise=="FRM")
         {
-          pays <- st_transform(sf_paysm(),"+init=epsg:4326 +proj=longlat +ellps=WGS84")
-          fra <- st_transform(sf_fram(),"+init=epsg:4326 +proj=longlat +ellps=WGS84")
-        }else
+          fond_pays <- st_transform(sf_paysm(),"+init=epsg:4326 +proj=longlat +ellps=WGS84")
+          fond_france <- st_transform(sf_fram(),"+init=epsg:4326 +proj=longlat +ellps=WGS84")
+        }else if(emprise!="999")
         {
-          if(dom=="971")
+          if(emprise=="971")
           {
-            fra <- st_transform(sf_reg01(),"+init=epsg:4326 +proj=longlat +ellps=WGS84")
-            pays <- fra
+            fond_france <- st_transform(sf_reg01(),"+init=epsg:4326 +proj=longlat +ellps=WGS84")
+            fond_pays <- fond_france
           }
-          if(dom=="972")
+          if(emprise=="972")
           {
-            fra <- st_transform(sf_reg02(),"+init=epsg:4326 +proj=longlat +ellps=WGS84")
-            pays <- fra
+            fond_france <- st_transform(sf_reg02(),"+init=epsg:4326 +proj=longlat +ellps=WGS84")
+            fond_pays <- fond_france
           }
-          if(dom=="973")
+          if(emprise=="973")
           {
-            fra <- st_transform(sf_reg03(),"+init=epsg:4326 +proj=longlat +ellps=WGS84")
-            pays <- st_transform(sf_pays973(),"+init=epsg:4326 +proj=longlat +ellps=WGS84")
+            fond_france <- st_transform(sf_reg03(),"+init=epsg:4326 +proj=longlat +ellps=WGS84")
+            fond_pays <- st_transform(sf_pays973(),"+init=epsg:4326 +proj=longlat +ellps=WGS84")
           }
-          if(dom=="974")
+          if(emprise=="974")
           {
-            fra <- st_transform(sf_reg04(),"+init=epsg:4326 +proj=longlat +ellps=WGS84")
-            pays <- fra
+            fond_france <- st_transform(sf_reg04(),"+init=epsg:4326 +proj=longlat +ellps=WGS84")
+            fond_pays <- fond_france
           }
-          if(dom=="976")
+          if(emprise=="976")
           {
-            fra <- st_transform(sf_reg06(),"+init=epsg:4326 +proj=longlat +ellps=WGS84")
-            pays <- fra
+            fond_france <- st_transform(sf_reg06(),"+init=epsg:4326 +proj=longlat +ellps=WGS84")
+            fond_pays <- fond_france
           }
-        }
-        fond_france <- fra
-        fond_pays <- pays
+        }else if(emprise=="999")
+        {
+          fond_france <- st_transform(fondEtranger,"+init=epsg:4326 +proj=longlat +ellps=WGS84")
+          fond_pays <- fond_france
+        }else{}
         
         return(list(fond_france,fond_pays))
       })
@@ -693,7 +712,7 @@ function(data,fondMaille,fondContour,fondSuppl=NULL,idDataDepart,idDataArrivee,v
           
           # AFFICHAGE DES FONDS D'HABILLAGE
           
-          if(dom %in% c("0","973"))
+          if(emprise %in% c("FRM","973"))
           {
             # fond des pays
             m <- addPolygons(map = m, data = fond_habillage_ou()[[2]][,"LIBGEO"], opacity = 1, # sauf la France
@@ -703,7 +722,7 @@ function(data,fondMaille,fondContour,fondSuppl=NULL,idDataDepart,idDataArrivee,v
                              fill = T, fillColor = "#CCCCCC", fillOpacity = 1
             )
           }
-          # fond de la France metro ou d'un DOM
+          # fond de la France metro, DOM ou etranger
           m <- addPolygons(map = m, data = fond_habillage_ou()[[1]][,"LIBGEO"], opacity = 1, # fond_france
                            stroke = TRUE, color = "black",
                            weight = 1.5,
@@ -801,7 +820,7 @@ function(data,fondMaille,fondContour,fondSuppl=NULL,idDataDepart,idDataArrivee,v
         
         clearGroup(map = proxy, group = "region")
         
-        if(dom=="0")
+        if(emprise=="FRM")
         {
           if(input$ajout_reg_ou_id)
           {
@@ -823,7 +842,7 @@ function(data,fondMaille,fondContour,fondSuppl=NULL,idDataDepart,idDataArrivee,v
         
         clearGroup(map = proxy, group = "departement")
         
-        if(dom=="0")
+        if(emprise=="FRM")
         {
           if(input$ajout_dep_ou_id)
           {
@@ -1155,20 +1174,20 @@ function(data,fondMaille,fondContour,fondSuppl=NULL,idDataDepart,idDataArrivee,v
       
       # TABLEAUX DE DONNEES, MAILLE ET CONTOUR
       
-      output$mydonnees_ou <- DT::renderDataTable(datatable({
+      output$mydonnees_ou <- DT::renderDataTable(DT::datatable({
         analyse_WGS84 <- analyse_apres_filtre_ou()[[1]]
         data <- as.data.frame(analyse_WGS84)
         tableau_donnees <- data[,c("CODE1","CODE2",varFlux)]
       },  style = 'bootstrap'
       ))
       
-      output$mymaille_ou <- DT::renderDataTable(datatable({
+      output$mymaille_ou <- DT::renderDataTable(DT::datatable({
         data <- as.data.frame(fondMaille)
         tableau_maille <- data[,c(1:2)]
       },  style = 'bootstrap'
       ))
       
-      output$mycontour_ou <- DT::renderDataTable(datatable({
+      output$mycontour_ou <- DT::renderDataTable(DT::datatable({
         data <- as.data.frame(fondContour)
         tableau_contour <- data[,c(1:2)]
       },  style = 'bootstrap'
